@@ -332,7 +332,7 @@ void pll::set_alpha(double alpha, int partition, bool optimisable) {
 void pll::set_frequencies(vector<double> freqs, int partition, bool optimisable) {
     _check_model_ready();
     _check_partitions_bounds(partition);
-    double old_fracchange = get_frac_change();
+    // double old_fracchange = get_frac_change();
     if (!_approx_eq(_vector_sum(freqs), 1)) {
         cerr << "Not setting frequencies: Frequencies do not sum to 1" << endl;
         throw exception();
@@ -342,12 +342,11 @@ void pll::set_frequencies(vector<double> freqs, int partition, bool optimisable)
         cerr << "Frequencies vector is the wrong length. Should be " << num_states << endl;
         throw exception();
     }
-    set_optimisable_frequencies(partition, true); // frequencies only updated if optimisable flag is true
+    // set_optimisable_frequencies(partition, true); // frequencies only updated if optimisable flag is true
     pllSetFixedBaseFrequencies(&(freqs[0]), num_states, partition, partitions, tr);
-    set_optimisable_frequencies(partition, optimisable);
-    double new_fracchange = get_frac_change();
-    _update_q_matrix_and_brlens(partition, old_fracchange, new_fracchange);
-
+    // set_optimisable_frequencies(partition, optimisable);
+    // double new_fracchange = get_frac_change();
+    // _update_q_matrix_and_brlens(partition, old_fracchange, new_fracchange);
 }
 
 void pll::link_alpha_parameters(string linkage) {
